@@ -8,8 +8,8 @@
 
         b must be an expression whose value is an element of Z, Q,
         R, C or Z/mZ, GF(p^n), an algebraic number, a polynomial over 
-        Z, Q, Z/mZ, GF(p^n) or a number field, a rational function or a 
-        square matrix over these structures.
+        Z, Q, Z/mZ, GF(p^n),a number field, R or C, a rational function
+        or a square matrix over these structures, if possible.
 
         e must be an expression whose value is a single precision
         number, a rational number with single precision numerator 
@@ -18,8 +18,8 @@
         If b is an element of Z, Q or R, e may be an integer, a 
         rational number or a real number; if e is a real number, b
         must be nonnegative.
-        If b is an element of C, e must be a rational number of the
-        form (s/2^t).
+        If b is an element of C, e must be an integer or a rational 
+        number of the form (s/2^t).
         If b is an element of Z/mZ, e must be a rational number of
         the form (s/2^t). If the modulus m is greater than 2^30, m
         must be a prime, but this primality is not tested.
@@ -27,8 +27,8 @@
         integer.
         If b is an element of GF(p^n), an algebraic number, a polynomial
         over Z or Q or a rational function, e must be an integer.
-        If b is a polynomial over Z/mZ, GF(p^n) or a number field, e 
-        must be a nonnegative integer.
+        If b is a polynomial over Z/mZ, GF(p^n), a number field, R or C,
+        e must be a nonnegative integer.
         If b is a matrix, e must be an integer; if e is negative, 
         the matrix b must be invertible.
 
