@@ -1,4 +1,4 @@
-# include <config.h>
+# include <smconfig.h>
 # include <stdio.h>
 # include <setjmp.h>
 # include <ctype.h>
