@@ -1,23 +1,7 @@
-#include<config.h>
 #include <_pol4.h>
+
 #include <signal.h>
 
-# define putpm( r, P, V ) fputpm( r, P, V, stdout )
-
-#undef putgfsel
-# define putgfsel( a, V ) fputgfsel( a, V, stdout )
-
-#undef putgf2el
-# define putgf2el( G, a, V ) fputgf2el( G, a, V, stdout )
-
-#undef putpgfs
-# define putpgfs( r, P, VL, V ) fputpgfs( r, P, VL, V, stdout )
-
-#undef putpgf2
-# define putpgf2( r, G, P, VL, V ) fputpgf2( r, G, P, VL, V, stdout )
-
-# ifndef ___MX
-
 #undef printf
 #define printf yprintf
 
@@ -84,20 +68,20 @@
 # undef putpgf2
 # define putpgf2 yputpgf2
 
-#endif
-
 #define strcat2( s,a,b ) ( *s='\0', strcat(strcat(s,a),b) )
 #define  strcat3( s,a,b,c )  strcat( strcat2( s,a,b ), c )
 #define  strcat4( s,a,b,c,d )  strcat( strcat( strcat2( s,a,b ), c ), d )
 #define itoc(N) (N ? ( issingle(N) ? list2(list2(0,N),0) : list2(flcons(N,0,llength(N)),0) ) : 0)
 #define fltoc(N) (N ? list2(N,0) : 0)
 
+extern single ITERMAX;
+
 # define gf2elred(Gn,a,Gm)  udpm2togf2el(Gm,gf2eltoudpm2(Gn,a)) 
 # define gfselred(p,a,Gm) pmsrem(1,p,pitopms(1,a,p),Gm)
 
-# ifdef ___APOLLO
-# define ___APO_RAM    /** fuer APOLLO 3000, APOLLO 4500 **/
-# endif
+#ifdef apollo
+#define ___APO_RAM    /** fuer APOLLO **/
+#endif
 
 # ifdef ___LARGE_SYSTEM
 #define MAXLV 50000
@@ -107,11 +91,11 @@
 #define MAXL 10000
 # endif 
 
-#define  NUM_FUNC 180 
+#define  NUM_FUNC 196
 # ifdef ___APO_RAM
-# define VARLISTLENGTH 280
+# define VARLISTLENGTH 296
 # else
-#define  VARLISTLENGTH 480
+#define  VARLISTLENGTH 496
 # endif
 extern struct var{
 	char *varname;
@@ -121,29 +105,29 @@ extern struct var{
 
 # define USER_FUNC 50
 
+# ifdef ___SMALL_SYSTEM
+# define AVLENGTH 200
+# else
+# define AVLENGTH 500
+# endif
+
 extern char *funstr[USER_FUNC];
 
-char *malloc();
+extern obj AV[AVLENGTH];
+extern char AVNAME[3];
+
+char *malloc(), *ctime();
 long time();
 FILE *fopen();
 
 extern FILE *datei, *fpt[10];
 extern char *comm,*dhelp, *datn, *fname[10];
-extern single ps, hps, cellc, cellabs, tdiff, tabs, statsch, owsch, owalt, fz, DIGITS, OUTPUTDIG, MX, MXNUM, MXUSER, DEPTH;
+extern single ps, hps, cellc, cellabs, tdiff, tabs, statsch, owsch, owalt, fz; 
+extern single DIGITS, OUTPUTDIG, MX, MXNUM, MXUSER, DEPTH, LINELN, outct;
 extern floating HEIGHTBOUND;
 extern single ecqnfsch, ecsch, modsch, ssch, pzsch, nfsch, gfsch; 
-extern single gfchar;
+extern single gfchar, nfon, avsch;
 extern single fosch, schleife, breaksch;
 extern single assch,prfehl;
 extern list VNF, VGF;
 extern single anzloc, funktion;
-
-#ifdef ___MX
-# ifndef ___MX300
-char *gctime();
-# else
-char *ctime();
-# endif
-# else
-char *ctime();
-# endif
